@@ -4,7 +4,7 @@ use 5.010;
 use common::sense;
 
 BEGIN {
-	$Spreadsheet::Wright::CSV::VERSION   = '0.103';
+	$Spreadsheet::Wright::CSV::VERSION   = '0.104';
 	$Spreadsheet::Wright::CSV::AUTHORITY = 'cpan:TOBYINK';
 }
 
@@ -12,7 +12,7 @@ use Carp;
 use Encode;
 use Text::CSV;
 
-use base qw(Spreadsheet::Wright);
+use parent qw(Spreadsheet::Wright);
 
 sub new
 {
