@@ -4,14 +4,14 @@ use 5.010;
 use common::sense;
 
 BEGIN {
-	$Spreadsheet::Wright::HTML::VERSION   = '0.103';
+	$Spreadsheet::Wright::HTML::VERSION   = '0.104';
 	$Spreadsheet::Wright::HTML::AUTHORITY = 'cpan:TOBYINK';
 }
 
 use Carp;
 use HTML::HTML5::Writer;
 
-use base qw(Spreadsheet::Wright::XHTML);
+use parent qw(Spreadsheet::Wright::XHTML);
 
 sub _make_output
 {
